'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _numeral = require('numeral');

var _numeral2 = _interopRequireDefault(_numeral);

var _pluralsCldr = require('plurals-cldr');

var _pluralsCldr2 = _interopRequireDefault(_pluralsCldr);

var _numeralLanguages = require('./numeralLanguages');

var _numeralLanguages2 = _interopRequireDefault(_numeralLanguages);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var DEFAULT_LOCALE = 'en';

var I18n = function () {
  function I18n(translations, supportedLocales) {
    _classCallCheck(this, I18n);

    this.translations = translations;
    this.supportedLocales = supportedLocales;
    this.locale = 'en';
  }

  _createClass(I18n, [{
    key: 'setLocale',
    value: function setLocale(locale) {
      this.locale = locale;

      if (_numeralLanguages2.default[locale]) {
        _numeral2.default.locales[locale] = _numeralLanguages2.default[locale];
        _numeral2.default.locale(locale);
      }
    }

    /**
     * Leverages `numeral` for number formatting
     */

  }, {
    key: 'formatNumber',
    value: function formatNumber(format, number) {
      return (0, _numeral2.default)(number).format(format);
    }

    /**
     * Retrieves a key from the translations object.
     */

  }, {
    key: 'getKey',
    value: function getKey(path) {
      var _this = this;

      var result = _lodash2.default.at(this.translations[this.locale], path)[0] || _lodash2.default.at(this.translations[DEFAULT_LOCALE], path)[0];

      if (process.env.NODE_ENV === 'development') {
        // We check that the translation exists in all current supportedLocales!
        this.supportedLocales.forEach(function (locale) {
          if (_lodash2.default.at(_this.translations[locale], path)[0]) return;

          console.warn('Key not found "' + path + '" with the locale "' + locale + '"');
        });
      }

      return result;
    }

    /**
     * Translate a key
     * Interpolate values with %{name}
     *
     * Examples:
     *
     * t('foo.bar') => 'Bar'
     * t('zemba.fleiba', {num: 3 }) => 'Zemba 3 Fleiba!'
     */

  }, {
    key: 't',
    value: function t(path, opts) {
      var value = this.getKey(path);
      if (typeof value !== 'string') {
        throw new Error('Key "' + path + '"is not a leaf');
      }
      var MATCH = /%\{([^}]+)\}/g;

      return value.replace(MATCH, function (match, subst) {
        if (!opts) {
          throw new Error('Translation "' + path + '" has a missing interpolation value "' + subst + '"');
        }
        return _lodash2.default.escape(String(opts[subst]));
      });
    }

    /**
     * Translate singular o plural copies
     * Options must contain `count`
     *
     * Examples:
     *
     * tp('beer', { count: 3 }) => '3 beers'
     */

  }, {
    key: 'tp',
    value: function tp(path, opts) {
      var num = opts.count;

      if (typeof num !== 'number') {
        throw new Error('You must have a `count` property');
      }

      var form = (0, _pluralsCldr2.default)(this.locale, num);
      var pluralPath = path + '.' + form;

      return this.t(pluralPath, opts);
    }

    /**
     * Conditional copies, made easy.
     * Provide a path and then options, like classNames
     *
     * Example:
     *
     *   tx('fleiba.zemba', user.get('role'))
     */

  }, {
    key: 'tx',
    value: function tx(path, variable, opts) {
      var newPath = path + '.' + variable;
      return this.t(newPath, opts);
    }
  }]);

  return I18n;
}();

exports.default = I18n;